@@ -125,6 +125,8 @@ class ContentActiveCensor(Base, StatsFull):
     ActiveCensors = Column(Text, default=None)
     rb_activecensor_count = Column(Integer, default=None)
 
+    Content = relationship("DjmdContent")
+
 
 class ContentCue(Base, StatsFull):
 
@@ -135,6 +137,8 @@ class ContentCue(Base, StatsFull):
     Cues = Column(Text, default=None)
     rb_cue_count = Column(Integer, default=None)
 
+    Content = relationship("DjmdContent")
+
 
 class ContentFile(Base, StatsFull):
 
@@ -156,19 +160,23 @@ class ContentFile(Base, StatsFull):
     rb_priority = Column(Integer, default=50)
     rb_file_size_dirty = Column(Integer, default=0)
 
+    Content = relationship("DjmdContent")
+
 
 class DjmdActiveCensor(Base, StatsFull):
 
     __tablename__ = "djmdActiveCensor"
 
     ID = Column(VARCHAR(255), primary_key=True)
-    ContentID = Column(VARCHAR(255), default=None)
+    ContentID = Column(VARCHAR(255), ForeignKey("djmdContent.ID"), default=None)
     InMsec = Column(Integer, default=None)
     OutMsec = Column(Integer, default=None)
     Info = Column(Integer, default=None)
     ParameterList = Column(Text, default=None)
     ContentUUID = Column(VARCHAR(255), default=None)
 
+    Content = relationship("DjmdContent")
+
 
 class DjmdAlbum(Base, StatsFull):
 
@@ -312,6 +320,69 @@ class DjmdContent(Base, StatsFull):
         s = f"{self.ID: <10} Title={self.Title}"
         return f"<{self.__class__.__name__}({s})>"
 
+    @property
+    def ArtistName(self) -> str:
+        try:
+            return self.Artist.Name
+        except AttributeError:
+            return ""
+
+    @property
+    def AlbumName(self) -> str:
+        try:
+            return self.Album.Name
+        except AttributeError:
+            return ""
+
+    @property
+    def GenreName(self) -> str:
+        try:
+            return self.Genre.Name
+        except AttributeError:
+            return ""
+
+    @property
+    def RemixerName(self) -> str:
+        try:
+            return self.Remixer.Name
+        except AttributeError:
+            return ""
+
+    @property
+    def LabelName(self) -> str:
+        try:
+            return self.Label.Name
+        except AttributeError:
+            return ""
+
+    @property
+    def OrgArtistName(self) -> str:
+        try:
+            return self.OrgArtist.Name
+        except AttributeError:
+            return ""
+
+    @property
+    def KeyName(self) -> str:
+        try:
+            return self.Key.ScaleName
+        except AttributeError:
+            return ""
+
+    @property
+    def ColorName(self) -> str:
+        try:
+            return self.Color.Commnt
+        except AttributeError:
+            return ""
+
+    @property
+    def ComposerName(self) -> str:
+        try:
+            return self.Composer.Name
+        except AttributeError:
+            return ""
+
 
 class DjmdCue(Base, StatsFull):
 
@@ -392,6 +463,7 @@ class DjmdSongHistory(Base, StatsFull):
     TrackNo = Column(Integer, default=None)
 
     History = relationship("DjmdHistory", back_populates="Songs")
+    Content = relationship("DjmdContent")
 
 
 class DjmdHotCueBanklist(Base, StatsFull):
@@ -441,6 +513,8 @@ class DjmdSongHotCueBanklist(Base, StatsFull):
         VARCHAR(255), ForeignKey("djmdHotCueBanklist.UUID"), default=None
     )
 
+    Content = relationship("DjmdContent")
+
 
 class DjmdKey(Base, StatsFull):
 
@@ -491,6 +565,8 @@ class DjmdMixerParam(Base, StatsFull):
     PeakHigh = Column(Integer, default=None)
     PeakLow = Column(Integer, default=None)
 
+    Content = relationship("DjmdContent")
+
 
 class DjmdMyTag(Base, StatsFull):
 
@@ -519,6 +595,7 @@ class DjmdSongMyTag(Base, StatsFull):
     TrackNo = Column(Integer, default=None)
 
     MyTag = relationship("DjmdMyTag", back_populates="MyTags")
+    Content = relationship("DjmdContent")
 
 
 class DjmdPlaylist(Base, StatsFull):
@@ -550,6 +627,7 @@ class DjmdSongPlaylist(Base, StatsFull):
     TrackNo = Column(Integer, default=None)
 
     Playlist = relationship("DjmdPlaylist", back_populates="Songs")
+    Content = relationship("DjmdContent")
 
 
 class DjmdRelatedTracks(Base, StatsFull):
@@ -582,6 +660,7 @@ class DjmdSongRelatedTracks(Base, StatsFull):
     TrackNo = Column(Integer, default=None)
 
     RelatedTracks = relationship("DjmdRelatedTracks", back_populates="Songs")
+    Content = relationship("DjmdContent")
 
 
 class DjmdSampler(Base, StatsFull):
@@ -611,6 +690,7 @@ class DjmdSongSampler(Base, StatsFull):
     TrackNo = Column(Integer, default=None)
 
     Sampler = relationship("DjmdSampler", back_populates="Songs")
+    Content = relationship("DjmdContent")
 
 
 class DjmdSongTagList(Base, StatsFull):
@@ -621,6 +701,8 @@ class DjmdSongTagList(Base, StatsFull):
     ContentID = Column(VARCHAR(255), ForeignKey("djmdContent.ID"), default=None)
     TrackNo = Column(Integer, default=None)
 
+    Content = relationship("DjmdContent")
+
 
 class DjmdSort(Base, StatsFull):
 
